package com.ruoyi.execution.produce.dispersed.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.execution.produce.dispersed.enetity.BpmExecuteProcess;
import com.ruoyi.system.entity.runbpm.IntoProduction;

/**
 * 流程执行任务Service接口
 *
 * @author hzh
 * @date 2023-11-01
 */
public interface IBpmExecuteProcessService {
    /**
     * 查询流程执行任务
     *
     * @param id 流程执行任务主键
     * @return 流程执行任务
     */
    public BpmExecuteProcess selectBpmExecuteProcessById(Long id);

    /**
     * 查询流程执行任务列表
     *
     * @param bpmExecuteProcess 流程执行任务
     * @return 流程执行任务集合
     */
    public List<BpmExecuteProcess> selectBpmExecuteProcessList(BpmExecuteProcess bpmExecuteProcess);

    /**
     * 新增流程执行任务
     *
     * @param bpmExecuteProcess 流程执行任务
     * @return 结果
     */
    public int insertBpmExecuteProcess(BpmExecuteProcess bpmExecuteProcess);

    /**
     * 修改流程执行任务
     *
     * @param bpmExecuteProcess 流程执行任务
     * @return 结果
     */
    public int updateBpmExecuteProcess(BpmExecuteProcess bpmExecuteProcess);

    /**
     * 批量删除流程执行任务
     *
     * @param ids 需要删除的流程执行任务主键集合
     * @return 结果
     */
    public int deleteBpmExecuteProcessByIds(Long[] ids);

    /**
     * 删除流程执行任务信息
     *
     * @param id 流程执行任务主键
     * @return 结果
     */
    public int deleteBpmExecuteProcessById(Long id);


    /**
     * 共通投产流程接口
     *
     * @param intoProduction 预执行流程任务实体
     * @return
     */
    public AjaxResult productionScheduling(IntoProduction intoProduction);
}
